@@ -259,7 +259,7 @@ struct spvm_env {
   void* reserved159;
   int32_t (*get_instance_method_id_static)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, const char* method_name);
   int32_t (*get_bool_object_value)(SPVM_ENV* env, SPVM_VALUE* stack, void* bool_object);
-  void (*cleanup_global_vars)(SPVM_ENV* env);
+  void (*cleanup_global_vars)(SPVM_ENV* env, SPVM_VALUE* stack);
   void (*make_read_only)(SPVM_ENV* env, SPVM_VALUE* stack, void* string);
   int32_t (*is_read_only)(SPVM_ENV* env, SPVM_VALUE* stack, void* string);
   int32_t (*is_array)(SPVM_ENV* env, SPVM_VALUE* stack, void* object);
@@ -279,7 +279,7 @@ struct spvm_env {
   void (*print)(SPVM_ENV* env, SPVM_VALUE* stack, void* string);
   void (*print_stderr)(SPVM_ENV* env, SPVM_VALUE* stack, void* string);
   int32_t (*init_env)(SPVM_ENV* env);
-  void (*call_init_blocks)(SPVM_ENV* env);
+  void (*call_init_blocks)(SPVM_ENV* env, SPVM_VALUE* stack);
   int32_t (*get_class_id)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name);
   SPVM_VALUE* (*new_stack)(SPVM_ENV* env);
   void (*free_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
@@ -290,8 +290,8 @@ struct spvm_env {
   void* (*new_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, size_t size);
   void (*free_memory_stack)(SPVM_ENV* env, SPVM_VALUE* stack, void* block);
   int32_t (*get_memory_blocks_count_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
-  int32_t (*set_command_info_program_name)(SPVM_ENV* env, void* obj_program_name);
-  int32_t (*set_command_info_argv)(SPVM_ENV* env, void* obj_argv);
+  int32_t (*set_command_info_program_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* obj_program_name);
+  int32_t (*set_command_info_argv)(SPVM_ENV* env, SPVM_VALUE* stack, void* obj_argv);
   int32_t (*get_class_id_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, int32_t* error, const char* file, int32_t line);
   const char* (*strerror)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t errno_value, int32_t length);
   void* (*new_string_array)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t length);
@@ -335,8 +335,8 @@ struct spvm_env {
 };
 
 struct spvm_env_runtime {
-  void* (*new_object)();
-  void (*free_object)(void* runtime);
+  void* (*new_runtime)();
+  void (*free_runtime)(void* runtime);
   void (*prepare)(void* runtime);
   int32_t* (*get_opcodes)(void* runtime);
   int32_t (*get_opcodes_length)(void* runtime);
@@ -425,8 +425,8 @@ struct spvm_env_runtime {
 };
 
 struct spvm_env_compiler {
-  void* (*new_object)();
-  void (*free_object)(void* compiler);
+  void* (*new_compiler)();
+  void (*free_compiler)(void* compiler);
   void (*set_start_line)(void* compiler, int32_t start_line);
   int32_t (*get_start_line)(void* compiler);
   void (*set_start_file)(void* compiler, const char* start_file);
@@ -434,15 +434,15 @@ struct spvm_env_compiler {
   void (*add_module_dir)(void* compiler, const char* module_dir);
   int32_t (*get_module_dirs_length )(void* compiler);
   const char* (*get_module_dir )(void* compiler, int32_t module_dir_id);
-  int32_t (*compile)(void* compiler, const char* class_name);
+  int32_t (*compile_spvm)(void* compiler, const char* class_name);
   int32_t (*get_error_messages_length)(void* compiler);
   const char* (*get_error_message)(void* compiler, int32_t index);
   int32_t* (*create_spvm_32bit_codes)(void* compiler, void* allocator);
 };
 
 struct spvm_env_precompile {
-  void* (*new_object)();
-  void (*free_object)(void* precompile);
+  void* (*new_precompile)();
+  void (*free_precompile)(void* precompile);
   void (*set_runtime)(void* precompile, void* runtime);
   void* (*get_runtime)(void* precompile);
   void (*build_class_source)(void* precompile, void* string_buffer, const char* class_name);
@@ -502,13 +502,13 @@ enum {
 };
 
 struct spvm_env_allocator {
-  void* (*new_object)();
-  void (*free_object)(void* allocator);
+  void* (*new_allocator)();
+  void (*free_allocator)(void* allocator);
 };
 
 struct spvm_env_string_buffer {
-  void* (*new_object)();
-  void (*free_object)(void* string_buffer);
+  void* (*new_string_buffer_tmp)();
+  void (*free_string_buffer)(void* string_buffer);
   const char* (*get_value)(void* string_buffer);
   int32_t (*get_length)(void* string_buffer);
 };
