@@ -197,7 +197,7 @@ const char* SPVM_COMPILER_get_runtime_name(SPVM_HASH* runtime_string_symtable, c
   return new_name;
 }
 
-int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
+int32_t SPVM_COMPILER_compile_spvm(SPVM_COMPILER* compiler, const char* class_name) {
   
   SPVM_CONSTANT_STRING* class_name_string = SPVM_CONSTANT_STRING_new(compiler, class_name, strlen(class_name));
   class_name = class_name_string->value;
