@@ -438,22 +438,6 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "TYPE_CONVERSION_LONG_OBJECT_TO_LONG",
     "TYPE_CONVERSION_FLOAT_OBJECT_TO_FLOAT",
     "TYPE_CONVERSION_DOUBLE_OBJECT_TO_DOUBLE",
-    "SET_STACK_BYTE",
-    "SET_STACK_SHORT",
-    "SET_STACK_INT",
-    "SET_STACK_LONG",
-    "SET_STACK_FLOAT",
-    "SET_STACK_DOUBLE",
-    "SET_STACK_OBJECT",
-    "SET_STACK_REF",
-    "SET_STACK_UNDEF",
-    "SET_STACK_MULNUM_BYTE",
-    "SET_STACK_MULNUM_SHORT",
-    "SET_STACK_MULNUM_INT",
-    "SET_STACK_MULNUM_LONG",
-    "SET_STACK_MULNUM_FLOAT",
-    "SET_STACK_MULNUM_DOUBLE",
-    "CALL_METHOD",
     "GET_STACK_BYTE",
     "GET_STACK_SHORT",
     "GET_STACK_INT",
@@ -475,6 +459,21 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "GET_STACK_OPTIONAL_FLOAT",
     "GET_STACK_OPTIONAL_DOUBLE",
     "GET_STACK_OPTIONAL_OBJECT",
+    "SET_STACK_BYTE",
+    "SET_STACK_SHORT",
+    "SET_STACK_INT",
+    "SET_STACK_LONG",
+    "SET_STACK_FLOAT",
+    "SET_STACK_DOUBLE",
+    "SET_STACK_OBJECT",
+    "SET_STACK_REF",
+    "SET_STACK_UNDEF",
+    "SET_STACK_MULNUM_BYTE",
+    "SET_STACK_MULNUM_SHORT",
+    "SET_STACK_MULNUM_INT",
+    "SET_STACK_MULNUM_LONG",
+    "SET_STACK_MULNUM_FLOAT",
+    "SET_STACK_MULNUM_DOUBLE",
     "RETURN_VOID",
     "RETURN_BYTE",
     "RETURN_SHORT",
@@ -490,6 +489,10 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "RETURN_MULNUM_LONG",
     "RETURN_MULNUM_FLOAT",
     "RETURN_MULNUM_DOUBLE",
+    "ITEMS",
+    "CALL_CLASS_METHOD",
+    "CALL_INSTANCE_METHOD_STATIC",
+    "CALL_INSTANCE_METHOD_DYNAMIC",
   };
   
   return id_names;
