@@ -1893,7 +1893,7 @@ Examples:
 
 =head2 cleanup_global_vars
   
-  void (*cleanup_global_vars)(SPVM_ENV* env);
+  void (*cleanup_global_vars)(SPVM_ENV* env, SPVM_VALUE* stack);
 
 Cleanup gloval variable, such as class variables and the exception variable.
 
@@ -2083,7 +2083,7 @@ Returns the count of the memory blocks on the stack.
 
 =head2 set_command_info_program_name
 
-  int32_t (*set_command_info_program_name)(SPVM_ENV* env, void* obj_program_name);
+  int32_t (*set_command_info_program_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* obj_program_name);
 
 Sets the program name. This value is got by L<CommandInfo->PROGRAM_NAME|SPVM::CommandInfo/"PROGRAM_NAME">.
 
@@ -2093,7 +2093,7 @@ The program name must be a C<string> object. Otherwise return non-zero value.
 
 =head2 set_command_info_argv
 
-  int32_t (*set_command_info_argv)(SPVM_ENV* env, void* obj_argv);
+  int32_t (*set_command_info_argv)(SPVM_ENV* env, SPVM_VALUE* stack, void* obj_argv);
 
 Sets the argv. This value is got by L<CommandInfo->ARGV|SPVM::CommandInfo/"ARGV">.
 
