@@ -105,7 +105,9 @@ Runtime native APIs have its IDs.
   81 build
   82 get_class_parent_class_id
   83 get_method_required_args_length
-  84 get_method_required_args_length
+  84 get_class_is_pointer
+  85 get_method_is_enum
+  86 get_type_flag
 
 =head1 Runtime Native APIs
 
@@ -454,3 +456,12 @@ Reserved.
 =head2 get_class_is_pointer
 
   int32_t (*get_class_is_pointer)(void* runtime, int32_t class_id);
+
+=head2 get_method_is_enum
+
+  int32_t (*get_class_is_pointer)(void* runtime, int32_t class_id);
+
+=head2 get_type_flag
+
+  int32_t (*get_type_flag)(void* runtime, int32_t type_id);
+
